pygeodesy.ellipsoidalGeodSolve.LatLon

Package pygeodesy :: Module ellipsoidalGeodSolve :: Class LatLon |
[frames] | no frames]

# Class LatLon

                   object --+
                            |
                 named._Named --+
                                |
                 named._NamedBase --+
                                    |
                   object --+       |
                            |       |
                 named._Named --+   |
                                |   |
            ecefLocals._EcefLocal --+
                                    |
                latlonBase.LatLonBase --+
                                        |
    ellipsoidalBase.LatLonEllipsoidalBase --+
                                            |
    ellipsoidalBaseDI.LatLonEllipsoidalBaseDI --+
                                                |
                                               LatLon

An ellipsoidal LatLon like ellipsoidalKarney.LatLon but using (exact) geodesic wrapper GeodesicSolve to compute the geodesic distance, initial and final bearing (azimuths) between two given points or the destination point given a start point and an (initial) bearing.

Instance Methods
toCartesian(self, **Cartesian_datum_kwds) Convert this point to exact cartesian (ECEF) coordinates. |
Inherited from `ellipsoidalBaseDI.LatLonEllipsoidalBaseDI`: `bearingTo2`, `destination`, `destination2`, `distanceTo`, `distanceTo3`, `finalBearingOn`, `finalBearingTo`, `initialBearingTo`, `intermediateTo`, `intersecant2`, `nearestOn8`, `plumbTo` Inherited from `ellipsoidalBase.LatLonEllipsoidalBase`: `__init__`, `antipode`, `convertDatum`, `convertRefFrame`, `distanceTo2`, `elevation2`, `ellipsoid`, `ellipsoids`, `geoidHeight2`, `intersection3`, `intersections2`, `isenclosedBy`, `midpointTo`, `nearestOn`, `parse`, `to3xyz`, `toCss`, `toDatum`, `toEtm`, `toLcc`, `toMgrs`, `toOsgr`, `toRefFrame`, `toTransform`, `toUps`, `toUtm`, `toUtmUps`, `triangulate`, `trilaterate5` Inherited from `latlonBase.LatLonBase`: `PointsIter`, `__eq__`, `__ne__`, `__str__`, `bounds`, `boundsOf`, `chordTo`, `circin6`, `circum3`, `circum4_`, `compassAngle`, `compassAngleTo`, `cosineAndoyerLambertTo`, `cosineForsytheAndoyerLambertTo`, `cosineLawTo`, `destinationXyz`, `equals`, `equals3`, `equirectangularTo`, `euclideanTo`, `flatLocalTo`, `flatPolarTo`, `hartzell`, `haversineTo`, `height4`, `heightStr`, `hubenyTo`, `isantipode`, `isantipodeTo`, `isequalTo`, `isequalTo3`, `latlon2`, `latlon2round`, `latlon_`, `nearestOn6`, `nearestTo`, `normal`, `philam2`, `points`, `points2`, `radii11`, `rhumbAzimuthTo`, `rhumbDestination`, `rhumbDistanceTo`, `rhumbIntersecant2`, `rhumbLine`, `rhumbMidpointTo`, `thomasTo`, `to2ab`, `to3llh`, `toEcef`, `toNormal`, `toNvector`, `toStr`, `toVector`, `toVector3d`, `toWm`, `vincentysTo` Inherited from `named._NamedBase`: `__repr__`, `others`, `toRepr` Inherited from `ecefLocals._EcefLocal`: `toAer`, `toEnu`, `toLocal`, `toLtp`, `toNed`, `toXyz` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
| Equidistant Get the prefered azimuthal equidistant projection class (EquidistantGeodSolve).
| geodesicx Get this `LatLon`'s (exact) geodesic (GeodesicSolve).
| geodesic Get this `LatLon`'s (exact) geodesic (GeodesicSolve).
Inherited from `ellipsoidalBase.LatLonEllipsoidalBase`: `convergence`, `datum`, `ellipsoidalLatLon`, `epoch`, `gamma`, `iteration`, `reframe`, `scale` Inherited from `latlonBase.LatLonBase`: `clipid`, `height`, `isEllipsoidal`, `isSpherical`, `isnormal`, `lam`, `lat`, `latlon`, `latlonheight`, `lon`, `phi`, `philam`, `philamheight`, `sphericalLatLon`, `xyz`, `xyz3`, `xyzh` Inherited from `ecefLocals._EcefLocal`: `Ecef` Inherited from `named._Named`: `classname`, `classnaming`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### toCartesian (self, **Cartesian_datum_kwds) |
Convert this point to exact cartesian (ECEF) coordinates. Arguments: `Cartesian_datum_kwds` - Optional Cartesian, `datum` and other keyword arguments, ignored if `Cartesian is None`. Use `Cartesian=Class` to override this Cartesian class or set `Cartesian=None`. Returns: The cartesian (ECEF) coordinates (Cartesian) or if `Cartesian is None`, an Ecef9Tuple`(x, y, z, lat, lon, height, C, M, datum)` with `C` and `M` if available. Raises: `TypeError` - Invalid `Cartesian`, `datum` or other `Cartesian_datum_kwds`. Overrides: latlonBase.LatLonBase.toCartesian

Property Details

### Equidistant Get the prefered azimuthal equidistant projection class (EquidistantGeodSolve). Get method: Equidistant(self) - Get the prefered azimuthal equidistant projection class (EquidistantGeodSolve). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### geodesicx Get this `LatLon`'s (exact) geodesic (GeodesicSolve). Get method: geodesicx(self) - Get this `LatLon`'s (exact) geodesic (GeodesicSolve). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### geodesic Get this `LatLon`'s (exact) geodesic (GeodesicSolve). Get method: geodesicx(self) - Get this `LatLon`'s (exact) geodesic (GeodesicSolve). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.